"""Code to support the DOS heritage of most Norton Guide databases."""

##############################################################################
# Python compatibility hackage.
from __future__ import annotations

##############################################################################
# Python imports.
from typing import Final

##############################################################################
DOS_MAP: Final[dict[int, str]] = str.maketrans(
    {
        0: " ",
        1: "\u263a",
        2: "\u263b",
        3: "\u2665",
        4: "\u2666",
        5: "\u2663",
        6: "\u2660",
        7: "\u2022",
        8: "\u25db",
        9: "\u25cb",
        10: "\u25d9",
        11: "\u2642",
        12: "\u2640",
        13: "\u266a",
        14: "\u266b",
        15: "\u263c",
        16: "\u25ba",
        17: "\u25c4",
        18: "\u2195",
        19: "\u203c",
        20: "\u00b6",
        21: "\u00a7",
        22: "\u25ac",
        23: "\u21a8",
        24: "\u2191",
        25: "\u2193",
        26: "\u2192",
        27: "\u2190",
        28: "\u221f",
        29: "\u2194",
        30: "\u25b2",
        31: "\u25bc",
        127: "\u2302",
        128: "\u00c7",
        129: "\u00fc",
        130: "\u00e9",
        131: "\u00e2",
        132: "\u00e4",
        133: "\u00e0",
        134: "\u00e5",
        135: "\u00e7",
        136: "\u00ea",
        137: "\u00eb",
        138: "\u00e8",
        139: "\u00ef",
        140: "\u00ee",
        141: "\u00ec",
        142: "\u00c4",
        143: "\u00c5",
        144: "\u00c9",
        145: "\u00e6",
        146: "\u00c6",
        147: "\u00f4",
        148: "\u00f6",
        149: "\u00f2",
        150: "\u00fb",
        151: "\u00f9",
        152: "\u00ff",
        153: "\u00d6",
        154: "\u00dc",
        155: "\u00a2",
        156: "\u00a3",
        157: "\u00a5",
        158: "\u20a7",
        159: "\u0192",
        160: "\u00e1",
        161: "\u00ed",
        162: "\u00f3",
        163: "\u00fa",
        164: "\u00f1",
        165: "\u00d1",
        166: "\u00aa",
        167: "\u00ba",
        168: "\u00bf",
        169: "\u2319",
        170: "\u00ac",
        171: "\u00bd",
        172: "\u00bc",
        173: "\u00a1",
        174: "\u00ab",
        175: "\u00bb",
        176: "\u2591",
        177: "\u2592",
        178: "\u2593",
        179: "\u2502",
        180: "\u2524",
        181: "\u2561",
        182: "\u2562",
        183: "\u2556",
        184: "\u2555",
        185: "\u2563",
        186: "\u2551",
        187: "\u2557",
        188: "\u255d",
        189: "\u255c",
        190: "\u255b",
        191: "\u2510",
        192: "\u2514",
        193: "\u2534",
        194: "\u252c",
        195: "\u251c",
        196: "\u2500",
        197: "\u253c",
        198: "\u255e",
        199: "\u255f",
        200: "\u255a",
        201: "\u2554",
        202: "\u2569",
        203: "\u2566",
        204: "\u2560",
        205: "\u2550",
        206: "\u256c",
        207: "\u2567",
        208: "\u2568",
        209: "\u2564",
        210: "\u2565",
        211: "\u2559",
        212: "\u2558",
        213: "\u2552",
        214: "\u2553",
        215: "\u256b",
        216: "\u256a",
        217: "\u251b",
        218: "\u250c",
        219: "\u2588",
        220: "\u2584",
        221: "\u258c",
        222: "\u2590",
        223: "\u2580",
        224: "\u03b1",
        225: "\u00df",
        226: "\u0393",
        227: "\u03c0",
        228: "\u03a3",
        229: "\u03c3",
        230: "\u00b5",
        231: "\u03c4",
        232: "\u03a6",
        233: "\u039b",
        234: "\u03a9",
        235: "\u03b4",
        236: "\u221e",
        237: "\u03c6",
        238: "\u03b5",
        239: "\u2229",
        240: "\u2261",
        241: "\u00b1",
        242: "\u2265",
        243: "\u2264",
        244: "\u2320",
        245: "\u2321",
        246: "\u00f7",
        248: "\u00b0",
        249: "\u2219",
        250: "\u00b7",
        251: "\u221a",
        252: "\u207f",
        253: "\u00b2",
        254: "\u25a0",
        255: "\u00a0",
    }
)
"""Map For translating into DOS-a-like characters."""


##############################################################################
def make_dos_like(text: str) -> str:
    """Try and make a string from a guide capable of retaining DOS-likeness.

    Args:
        text: The text to convert.

    Returns:
        The converted text.
    """
    return text.translate(DOS_MAP)


### dosify.py ends here
